@@ -17,6 +17,7 @@ from __future__ import absolute_import
 import os
 import sys
 import traceback
+from distutils.spawn import find_executable
 import xenv
 
 import LbPlatformUtils.describe
@@ -1037,7 +1038,10 @@ class LbRun(xenv.Script):
         if self.opts.container == "singularity":
             self.log.debug("preparing singularity wrapper command")
             # wrap command in container
-            wrapper = ["singularity", "exec", "--bind", "/cvmfs", "--userns"]
+            # PATH might be changed when launching the environment so use an absolute filename
+            singularity_exe = find_executable("singularity")
+            self.log.debug("Using singularity at: %s", singularity_exe)
+            wrapper = [singularity_exe, "exec", "--bind", "/cvmfs", "--userns"]
             if "X509_USER_PROXY" in os.environ:
                 wrapper += ["--bind", os.environ["X509_USER_PROXY"]]
 
